@@ -13,6 +13,7 @@ from typedpy.structures import (
     FinalStructure,
     ImmutableField,
     unique,
+    ABCStructure
 )
 
 from typedpy.structures_reuse import (
@@ -84,6 +85,7 @@ from .serialization import (
     serialize_field,
     FunctionCall,
     deserialize_single_field,
+    HasTypes
 )
 
 from .serialization_wrappers import (
